@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-04-01'; # DATE
+our $DATE = '2023-06-18'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.024'; # VERSION
+our $VERSION = '1.025'; # VERSION
 
 use App::CSVUtils qw(gen_csv_util);
 
@@ -45,7 +45,7 @@ _
 
     writes_csv => 0,
 
-    tags => ['category:extracting-values'],
+    tags => ['category:extracting'],
 
     on_input_data_row => sub {
         my $r = shift;
@@ -103,7 +103,7 @@ App::CSVUtils::csv_get_cells - Get one or more cells from CSV
 
 =head1 VERSION
 
-This document describes version 1.024 of App::CSVUtils::csv_get_cells (from Perl distribution App-CSVUtils), released on 2023-04-01.
+This document describes version 1.025 of App::CSVUtils::csv_get_cells (from Perl distribution App-CSVUtils), released on 2023-06-18.
 
 =head1 FUNCTIONS
 
